<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\LoginGuard\Administrator\DataShape;

defined('_JEXEC') or die;

use Akeeba\Component\LoginGuard\Administrator\Table\TfaTable;

/**
 * @property string $name                Internal code of this TFA Method
 * @property string $display             User-facing name for this TFA Method
 * @property string $shortinfo           Short description of this TFA Method displayed to the user
 * @property string $image               URL to the logo image for this Method
 * @property bool   $canDisable          Are we allowed to disable it?
 * @property bool   $allowMultiple       Are we allowed to have multiple instances of it per user?
 * @property string $help_url            URL for help content
 * @property bool   $allowEntryBatching  Allow authentication against all entries of this TFA Method.
 *
 * @since       6.0.0
 */
class MethodDescriptor extends DataShapeObject
{
	/**
	 * Internal code of this TFA Method
	 *
	 * @var   string
	 * @since 6.0.0
	 */
	protected $name = '';

	/**
	 * User-facing name for this TFA Method
	 *
	 * @var   string
	 * @since 6.0.0
	 */
	protected $display = '';

	/**
	 * Short description of this TFA Method displayed to the user
	 *
	 * @var   string
	 * @since 6.0.0
	 */
	protected $shortinfo = '';

	/**
	 * URL to the logo image for this Method
	 *
	 * @var   string
	 * @since 6.0.0
	 */
	protected $image = '';

	/**
	 * Are we allowed to disable it?
	 *
	 * @var   bool
	 * @since 6.0.0
	 */
	protected $canDisable = true;

	/**
	 * Are we allowed to have multiple instances of it per user?
	 *
	 * @var   bool
	 * @since 6.0.0
	 */
	protected $allowMultiple = false;

	/**
	 * URL for help content
	 *
	 * @var   string
	 * @since 6.0.0
	 */
	protected $help_url = '';

	/**
	 * Allow authentication against all entries of this TFA Method.
	 *
	 * Otherwise authentication takes place against a SPECIFIC entry at a time.
	 *
	 * @var   bool
	 * @since 6.0.0
	 */
	protected $allowEntryBatching = false;

	/**
	 * Active authentication methods, used internally only
	 *
	 * @var   TfaTable[]
	 * @since 6.0.0
	 * @internal
	 */
	protected $active = [];

	public function addActiveMethod(TfaTable $record)
	{
		$this->active[$record->id] = $record;
	}
}