<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\LoginGuard\Administrator\Event;

defined('_JEXEC') or die;

use Akeeba\Component\LoginGuard\Administrator\Event\Backport\ResultAware;
use DomainException;
use Joomla\CMS\Event\AbstractImmutableEvent;
use Joomla\CMS\User\User;

/**
 * Concrete Event class for the onLoginGuardBeforeDisplayMethods event
 *
 * @package     Akeeba\Component\LoginGuard\Administrator\Event
 *
 * @since       6.0.0
 */
class BeforeDisplayMethods extends AbstractImmutableEvent
{
	use ResultAware;

	/** @inheritdoc */
	public function __construct(User $user)
	{
		parent::__construct('onLoginGuardBeforeDisplayMethods', [
			'user' => $user,
		]);
	}

	/**
	 * Validate the value of the 'user' named parameter
	 *
	 * @param   User  $value
	 *
	 * @return  User
	 * @since   6.0.0
	 */
	public function setUser(User $value): User
	{
		if (empty($value) || ($value->id <= 0) || ($value->guest == 1))
		{
			throw new DomainException(sprintf('Argument \'user\' of event %s must be a non-guest User object', $this->name));
		}

		return $value;
	}

}